"""Query client library."""

from mcipc.query.client import Client


__all__ = ['Client']
